define(['handlebars'], function(Handlebars) {

    /**
    Handlebars kommt von Haus aus ohne einfaches Array.join() daher. Dies wird
    hiermit bereit gestellt.

    @example
        JSON:
        ["Dresden", "Hamburg", "Leipzig"]

        Template:
        <p>{{join items delimiter=", "}}</p>

        HTML:
        <p>Dresden, Hamburg, Leipzig</p>
    **/
    Handlebars.registerHelper('join', function(items, options) {
        var delimiter  = options.hash.delimiter || ',',
            whitespace = options.hash.strip || 0,
            output     = items.join(delimiter);

        if (whitespace) {
            output += ' ' + (Handlebars.helpers.noWhitespace.apply(this, [output]));
        }

        return output;
    });

    /**
    Zu Seminar-Terminen bei sollen per Button bzw. E-Mail Anfragen getättigt werden
    können. Daher wird mittels des Helpers ein Button erzeugt.
    **/
    Handlebars.registerHelper('seminarButton', function(context) {
        var href,
            i = 0,
            item,
            items = context.dates,
            l = items.length,
            output = '',
            prefix = '<a data-role="button" data-mini="true" data-inline="true"' +
                     ' href="mailto:seminare@kiehl-group.com?subject={{href}}">',
            suffix = '</a>';


        for (; i < l; i++) {
            item = prefix;
            if (items[i].city) {
                item += items[i].city + ': ';
            }
            href = items[i].date + ': ' + context.description;
            item += items[i].date + suffix;
            output += item.replace('{{href}}', encodeURIComponent(href));
        }

        return new Handlebars.SafeString(output);

    });

    /**
    Standardmäßig werden HTML-Tags escaped und das muss an diversen Stellen
    unterbunden werden.
    **/
    Handlebars.registerHelper('ishtml', function(items) {
        return new Handlebars.SafeString(items);
    });

    /**
    Die deutschen Namen der Dokumente sind zu lang und müssen daher umgeschrieben
    werden. Da dies derzeit nicht im Backend geschieht, muss das beim Rendern
    geschehen.
    **/
    Handlebars.registerHelper('docname', function(items) {
        var item = items.toLowerCase(),
            replacements = {
                'informationsblatt'     : 'Informations-Blatt',
                'betriebsanweisung'     : 'Betriebs-Anweisung',
                'sicherheitsdatenblatt' : 'Sicherheits-Datenblatt',
                'transportinformation'  : 'Transport-Information',
                'zusatzinformation'     : 'Zusatz-Information'
            };

        if (replacements[item]) {
            return new Handlebars.SafeString(replacements[item]);
        } else {
            return new Handlebars.SafeString(items);
        }
    });

    /**
    Artikelnummer mal mit, mal ohne Leerzeichen, damit die Suche auch was findet.
    **/
    Handlebars.registerHelper('noWhitespace', function(item) {
        return item.replace(/\s/g, '');
    });

    /**
    Einfache Delegate-Funktion auf nativer JS-Basis

    @method addDelegateListener
    @param {String} type Event-Typ (click, touchstart, touchend)
    @param {String} nodeName Element-Typ (A, LI, SPAN, usw.)
    @param {Function} fn Callback
    **/
    Element.prototype.addDelegateListener = function(type, nodeName, fn) {

        this.addEventListener(type, function(e){
            var target = e.target;

            while(target && target.nodeName !== nodeName) {
                target = target.parentNode;
            }

            if(target && target !== this) {
                return fn.call(target, e);
            }

        }, false );
    };

});
