/**
 * provide a cross browser compliant log
 */

var debug = false;    // Config (Testsystem) oder per URL-Param aktivierbar

var log = window.log = function() {
    if (this.console && debug) {
        log.history = log.history || [];   // store logs to an array for reference
        log.history.push(arguments);
        console.log( Array.prototype.slice.call(arguments) );
    }
};

require.config({
    // modules
    paths: {
        'domReady'                : 'vendor/domReady',
        'jquery'                  : 'vendor/jquery.min',
        'jquery.mobile'           : 'vendor/jquery.mobile-1.3.0.min',
        'handlebars'              : 'vendor/handlebars',
        'AppHistory'              : 'modules/AppHistory',
        'CatalogController'       : 'modules/CatalogController',
        'CleaningController'      : 'modules/CleaningController',
        'Config'                  : 'modules/Config',
        'Consultants'             : 'modules/Consultants',
        'CoverageController'      : 'modules/CoverageController',
        'Eyecatcher'              : 'modules/Eyecatcher',
        'ExternalDataHandler'     : 'modules/ExternalDataHandler',
        'Languages'               : 'data/LanguageData',
        'LanguageController'      : 'modules/LanguageController',
        'LocalStorage'            : 'modules/LocalStorage',
        'PDFDialog'               : 'modules/PDFDialog',
        'ProcedureController'     : 'modules/ProcedureController',
        'ProductDetailController' : 'modules/ProductDetailController',
        'Scanner'                 : 'modules/BarcodeScanner',
        'SeminarController'       : 'modules/SeminarController',
        'SeminarDetailController' : 'modules/SeminarDetailController',
        'TechnicalRequest'        : 'modules/TechnicalRequest',
        'TemplateEngine'          : 'modules/TemplateEngine'
    },
    // dependencies
    shim: {
        'jquery' : {
            exports: 'jQuery'
        },
        'jquery.mobile' : ['jquery'],
        'handlebars' : {
            exports: 'Handlebars'
        }
    },
    urlArgs: 'rev=v6'    // production setting
    // urlArgs: 'rev=' + (new Date()).getTime()    // development setting
});

require(['domReady', 'jquery', 'app', 'Config', 'jquery.mobile'],
    function(domReady, $, App, Config) {

        'use strict';

        if (Config.debugging || window.location.search.match(/debug/)) {
            // for production enable debug mode by get param "?debug=true"
            debug = true;
        }

        // Active-State auf mobilen Devices nutzen
        document.addEventListener("touchstart", function () {}, true);

        // domReady is RequireJS plugin that triggers when DOM is ready
        domReady(function () {

            function onDeviceReady(desktop) {

                if (navigator.splashscreen) {
                    navigator.splashscreen.show();
                }

                Config.platform = (window.device && window.device.platform) ? window.device.platform : 'WebApp';
                Config.eventType = 'click';    // kein touchevent mehr verwenden

                window.plugins = window.plugins || {};
                if ('object' === typeof cordova && cordova.plugins) {
                    $.extend(window.plugins, cordova.plugins);
                }

                // globale Konfiguration für jQuery und jQuery Mobile
                $.support.cors = true;
                $.mobile.ajaxEnabled = false;
                $.mobile.allowCrossDomainPages = true;
                $.mobile.defaultPageTransition = 'fade';
                $.mobile.hashListeningEnabled = false;
                // $.mobile.linkBindingEnabled = false;
                $.mobile.pushStateEnabled = false;
                $.mobile.touchOverflowEnabled = true;

                App.initialise(desktop);

            }

            /*
            Wir checken nicht nur, ob es sich um ein mobiles Gerät handelt, sondern
            ob auch Phonegap aka Cordova initialisiert ist, sprich mit der nativen
            API und somit dem mobilen Endgerät spricht.
            */
            if (window.device && window.device.platform && window.device.platform.match(/Android|iOS|Win32NT/)) {
                // This is running on a device so waiting for deviceready event
                document.addEventListener('deviceready', onDeviceReady, false);
            } else {
                // On desktop don't have to wait for anything
                onDeviceReady(true);
            }

        });

    }
);
