define(['jquery', 'Config'], function($, Config) {

    'use strict';

    /**
    Auf Android-Geräten gibt es den Backbutton. Ein gelerntes Verhalten ist, dass
    man damit zurück im Browser und auch in Apps zurück gehen kann. Dies muss auch
    in der App bereit gestellt werden. Da die History an diversen Stellen manipuliert
    wird, müssen wir einen Call-Stack aufbauen. Dazu werden Referenzen zu allen
    zu berücksichtigenden Objekten gespeichert.

    @class AppHistory
    @constructor
    **/
    var AppHistory = (function() {

            /**
            Wir stecken die Startseite als erstes Element in den Stack.

            @property init
            @type String
            @default Config.pages.home
            **/
        var init = Config.pages.home,

            /**
            Referenz aller Objekte speichern.

            @property stack
            @type Array
            @default [$(init)]
            **/
            stack = [init];

        /**
        Gehe zur letzten gespeicherten Seite zurück.

        @method back
        **/
        function back() {
            if (1 < stack.length) {
                stack.pop();

                $.mobile.changePage($(stack[stack.length - 1]), {
                    reverse : true
                });
            }
        }

        /**
        Einen neuen Wert in den Stack schreiben. Aber nur, wenn dieser nicht in
        der Blacklist steht.

        @method push
        @param {Object} state jQuery-Objekt
        **/
        function push(state) {
            if (state === init) {
                reset();
            } else {
                if (state !== stack[stack.length - 1]) {
                    stack.push(state);
                }
            }
            log(stack, state);
        }

        /**
        Ist der User wieder auf der Startseite, dann wird auch der Stack zurück
        gesetzt.

        @method reset
        **/
        function reset() {
            stack = [init];
        }

        return {
            back : back,
            push : push
        };

    }());

    return AppHistory;

});