define(['jquery', 'Config'], function($, Config) {

    'use strict';

    log('Modul BarcodeScanner geladen!');

    /**
    Initialisiere den Barcodescanner und werfe ein CustomEvent, wenn ein Code
    gescannt wurde.

    @class BarcodeScanner
    @constructor
    **/
    var BarcodeScanner = (function() {

        /**
        Wenn das Cordova-Plugin bereit steht, initialisiere den Scanner. Die Verarbeitung
        übernimmt dann der *ProductDetailController*.

        @method scan
        **/
        function scan() {
            if (window.device) {
                window.plugins.barcodeScanner.scan(onSuccess, function(error) {
                    $(document).trigger('cAlert', 'scanner_failed');
                });
            } else {
                log('Ups, no device -> no scan');
            }
        }

        /**
        Barcode wurde gescannt, also holen wir das Produkt.

        **Hinweis:** in der Funktion können keine Events geworfen werden, daher
        sprechen wir hier direkt mit dem *ProduktDetailController*.

        @private
        @method onSuccess
        @param {Object} result vom Barcodescanner zurück gegebene Ergebnis
        **/
        function onSuccess(result) {

            if (!result.cancelled) {
                // Barcode erkannt - Produkt laden
                 $(document).trigger('cShowProduct', {
                    ean : result.text,
                    productId : 0,
                    origin : Config.pages.home
                });
            } else {
                Config.loader('hide');
            }
        }

        /**
        @return Public API
        **/
        return {
            scan : scan
        };

    }());

    return BarcodeScanner;

});