define(['jquery'], function($) {

    'use strict';

    log('Modul Config geladen!');

    /**
    Konfigurationen für die App

    @class Config
    **/
    var Config = {
        // baseUrl : 'http://databox.kochan.de:4759/',
        baseUrl : 'http://app.kiehl-group.com/',
        // baseUrl : 'http://${backend.host}/',
        debugging : false,
        realm : 'GR',
        platform : 'WebApp',
        revision : 14,     // change of revision leads to flush the localStorage
        externalPaths : {
            catalog    : 'app/products.php?device=phone&realm=GR&lang={lang}',
            cleaning   : 'app/cleaning_advice.php?device=phone&realm=GR&lang={lang}',
            procedure  : 'app/cleaning_procedure.php?device=phone&realm=GR&lang={lang}',
            consultant : 'app/search_consultant.php?device=phone&realm=GR&country={country}&zip={zip}',
            countries  : 'app/consultant_countries.php?device=phone&lang={lang}',
            product    : 'app/product_details.php?device=phone&lang={lang}&{product}',
            request    : 'app/technical_request.php?device=phone',
            seminar    : 'app/seminar_details.php?device=phone&id={seminar_id}&lang={lang}',
            seminars   : 'app/seminars.php?device=phone&realm=GR&lang={lang}'
        },
        localPaths : {
            language  : 'json/lang',
            templates : 'templates',
            pdfjs     : 'pdfjs/web/viewer.html?file='
        },
        // Keys für den LocalStorage
        storage : {
            hasApproved   : 'hasApproved',
            languageCode  : 'languageCode',
            languageData  : 'languageData',
            catalogData   : 'catalogData',
            cleaningData  : 'cleaningData',
            pdfHint       : 'pdfHintSeen',
            productPrefix : 'product_',
            procedureData : 'procedureData',
            revision      : 'revision',
            seminarData   : 'seminarData',
            seminarPrefix : 'seminar_'
        },
        // Seiten-Ids für die einzelnen Pages
        pages : {
            catalog    : '#catalog',
            cleaning1  : '#cleaning-step1',
            cleaning2  : '#cleaning-step2',
            cleaning3  : '#cleaning-step3',
            coverage   : '#coverage',
            details    : '#details',
            detail1    : '#detail-tab1',
            detail2    : '#detail-tab2',
            detail3    : '#detail-tab3',
            filter     : '#filter-layer',
            home       : '#home',
            language   : '#language',
            procedure1 : '#procedure-step1',
            procedure2 : '#procedure-step2',
            settings   : '#settings',
            seminar    : '#seminar-detail',
            seminars   : '#seminars',
            request    : '#technical-request',
            consultant : '#consultant',
            terms      : '#terms',
            imprint    : '#imprint',
            pdf        : '#pdf-view'
        },
        // Ids der Buttons, die den Scanner auslösen
        scanner : {
            home : '[href="#scanner"]'
        },
        // Ids der einzelnen Templates
        templates : {
            catalogList  : '#te_catalog',
            catalogPanel : '#te_catalog-panel',
            cleaning1    : '#te_cleaning-step1',
            cleaning2    : '#te_cleaning-step2',
            consultants  : '#te_consultants',
            countries    : '#te_countries',
            detail1      : '#te_detail-tab1',
            detail2      : '#te_detail-tab2',
            detail3      : '#te_detail-tab3',
            procedure1   : '#te_procedure-step1',
            procedure2   : '#te_procedure-step2',
            seminarList  : '#te_seminars',
            seminar      : '#te_seminar-detail'
        }
    };

    /**
    Wir sind sicher, dass wir an allen Stellen die Config haben. Also nutzen wir
    die Funktion, um bei unterstützenden Plattformen den nativen Ladedialog
    anzuzeigen. Ansonsten wird jQuery Mobile verwendet.

    @method loader
    @param {String} type *show* oder *hide*
    @param {String} text anzuzeigender String
    **/
    Config.loader = function(type, text) {
        if ('show' === type) {
            if (this.platform.match(/Android|iOS/)) {
                window.plugins.spinnerDialog.show(text || 'loading');
            } else {
                $.mobile.loading('show', {
                    textVisible : false,
                    theme : 'a',
                    html : ''
                });
            }
        } else {
            if (this.platform.match(/Android|iOS/)) {
                window.plugins.spinnerDialog.hide();
            } else {
                $.mobile.loading('hide');
            }
        }
    };

    return Config;
});
