/**
@module KIEHL
**/
define(['jquery', 'Config', 'LocalStorage'], function($, Config, LocalStorage) {

    'use strict';

    /**
    Weitere Apps von Kiehl werden per Störer platziert, sollen aber nur maximal
    5x angezeigt werden.

    @class Eyecatcher
    @constructor
    **/
    var Eyecatcher = (function Eyecatcher() {

            /**
            Wie oft soll der Störer angezeigt werden?

            @static
            @property maxCount
            @type {Number}
            @default 5
            **/
        var maxCount = 5,

            /**
            String für den LocalStorage.

            @static
            @property storageKey
            @type {String}
            @default eyecatcherCount
            **/
            storageKey = 'eyecatcherCount',

            /**
            DOM-Objekt, welches zu verwenden ist.

            @static
            @property dom
            @type {Object}
            @default $('#app-stoerer')
            **/
            dom = $('#app-stoerer');

        /**
        Prüfen, ob der Störer angezeigt werden soll. Wenn ja, dann abhängig vom
        Realm befüllen.

        @method init
        **/
        function init() {
            var count = parseInt(LocalStorage.get(storageKey) || 0, 10);

            if (count < maxCount && dom.length) {
                var img = $('img', dom),
                    imgSrc = img.attr('src'),
                    realm = Config.realm.toLowerCase(),
                    span = $('[data-translate=more-apps-gr]', dom);

                // Bildpfad setzen
                img.attr('src', imgSrc.replace('gr', realm));

                // Text setzen
                span.data('translate', 'more-apps-' + realm);

                initListener();

                // Zeitverzögernd anzeigen
                setTimeout(function() {
                    dom.removeClass('is-invisible');
                }, 3000);

                LocalStorage.set(storageKey, count + 1);
            }
        }

        /**
        Der Störer soll auch wieder geschlossen werden können.

        @private
        @method initListener
        **/
        function initListener() {
            $('.app-stoerer-close', dom).on(Config.eventType, function(e) {
                e.preventDefault();
                dom.addClass('is-invisible');
            });
        }

        /**
        @return public-API
        **/
        return {
            init : init
        };


    }());

    return Eyecatcher;

});
