define(function() {

    'use strict';

    log('Modul LocalStorage geladen!');

    /**
    Das Modul kümmert sich um die lokale Speicherung von Daten und stellt somit
    die Schnittstelle sowohl zum localStorage als auch zum sessionStorage dar.

    @class LocalStorage
    @constructor
    **/
    var LocalStorage = (function() {
        var storage = window.localStorage || localStorage,
            session = window.sessionStorage || sessionStorage;

        /**
        Lösche den gesamten local- und sessionStorage der App. Ausnahmen
        können übergeben werden, diese betreffen jedoch ausschließlich den
        localStorage.

        @method flush
        @param {Array} exceptions Liste aller nicht zu löschenden Daten
        **/
        function flush(exceptions) {
            var temp = {},
                i = 0,
                j,
                l = exceptions ? exceptions.length : 0;

            for (; i < l; i += 1) {
                temp[exceptions[i]] = get(exceptions[i]);
            }

            storage.clear();
            session.clear();

            for (j in temp) {
                if (temp.hasOwnProperty(j)) {
                    set(j, temp[j]);
                }
            }
        }

        /**
        Hole Daten aus dem local- oder sessionStorage

        @method get
        @param {String} key Wert, der aus dem local- oder lessionStorage geholt werden soll
        @return {Object} geparster Wert oder 'null', wenn nicht im localStorage
        **/
        function get(key) {
            // wir speichern entweder permanent oder temporär
            var data = storage.getItem(key) || session.getItem(key);
            if (data) {
                return JSON.parse(data);
            } else {
                return null;
            }
        }

        /**
        Lösche Daten aus dem localStorage

        @method rm
        @param {String} key Wert, der aus dem local- oder sessionStorage gelöscht werden soll
        @param {Boolean} temp lediglich während der Session gespeicherten Wert löschen
        **/
        function rm(key, temp) {
            if (temp) {
                session.removeItem(key);
            } else {
                storage.removeItem(key);
            }
        }

        /**
        Key-Value Parameter in den local- oder sessionStorage schreiben.
        Vorher wird der Inhalt noch serialisiert.

        @method set
        @param {String} key Wert, der im localStorage gesetzt werden soll
        @param {Object} value zu speichernde Daten
        @param {Boolean} temp lediglich während der Session speichern
        **/
        function set(key, value, temp) {
            var data = JSON.stringify(value);
            if (temp) {
                session.setItem(key, data);
            } else {
                storage.setItem(key, data);
            }
        }

        /**
        @return public API
        **/
        return {
            flush : flush,
            get   : get,
            rm    : rm,
            set   : set
        };

    })();

    return LocalStorage;

});
