define(['jquery', 'handlebars', 'helpers'], function($, Handlebars) {

    'use strict';

    log('Modul TemplateEngine geladen!');

    /**
    Module-Pattern, da wir nur eine TemplateEngine benötigen.

    @class TemplateEngine
    @constructor
    **/
    var TemplateEngine = (function() {

        var langcode = 'DE',
            strings;    // Fallback

        /**
        Übersetze alle Stellen in der UI, die mittels des Konstrukts
        <span data-translate="languageKey">Fallback-Text</span> versehen sind.

        @method translate
        @param {Object} data Sprachpaket
        @param {Object} obj Kontext oder Elemente, wo zu übersetzen ist
        @param {String} code Sprachkürzel - DE, EN, FR oder IT
        **/
        function translate(data, obj, code) {
            var dom = obj || {},
                context = dom.context || document,
                element = dom.element || null,
                collection = element ? $(element) : $('[data-translate]', context),
                i = 0,
                l = collection.length;

            langcode = code || langcode;
            strings = data || strings;

            for (; i < l; i += 1) {
                log($(collection[i]).data('translate'));
                change($(collection[i]), data[$(collection[i]).data('translate')],
                        $(collection[i]).data('translate'));
            }
        }

        /**
        Wir unterscheiden lediglich zwischen einem gewrappten Text und einem
        input-Feld. Bei einem SPAN wird der Text ersetzt, bei einem input-Feld
        der Placeholder angepasst.

        @private
        @method change
        @param {Object} obj das HTML-Object, welches lokalisiert werden soll
        @param {String} value die zu verwendende Zeichenkette
        @param {String} pattern Links werden gesondert betrachtet, hier brauchst
            das Pattern
        **/
        function change(obj, value, pattern) {
            if (obj.is('input')) {
                obj.attr('placeholder', value);
            } else if (obj.is('span')) {
                obj.html(value);
            } else if (obj.is('iframe')) {
                obj.attr('src', pattern.replace(/\{lang\}/, langcode));
            }
        }

        /**
        Render Template mit Handlebars

        @method render
        @param {String} templateId ID des zu verwendenden Templates
        @param {Object} data zu parsenden Daten
        @return {String} geparstes HTML
        **/
        function render(templateId, data) {
            var source = $(templateId).html(),
                template = Handlebars.compile(source),
                output = $(template(data));

            translate(strings, {
                context : output
            });

            return output;
        }

        /**
        @return public API
        **/
        return {
            render     : render,
            translate  : translate
        };

    }());

    return TemplateEngine;
});
